@@ -5,7 +5,7 @@ test_that("manage_na works as expected", {
         expect_identical(c(TRUE, FALSE, FALSE, FALSE, FALSE))
     manage_na(c(NA, -1, NA, 1, 10), lead_tail_only = FALSE) |> 
         expect_identical(c(TRUE, FALSE, TRUE, FALSE, FALSE))
-    manage_na(c(NA, 0, NA, 1, 10), lead_tail_only = FALSE, ig_zero = TRUE) |>
+    manage_na(c(NA, 0, NA, 1, 10), lead_tail_only = FALSE, ig = c(NA, 0)) |>
         expect_identical(c(TRUE, TRUE, TRUE, FALSE, FALSE))
     
     data(raman_hdpe)
@@ -23,6 +23,14 @@ test_that("manage_na works as expected", {
 })
 
 
+test_that("manage_na works with zeros", {
+    data(raman_hdpe)
+    raman_hdpe$spectra[[1]][1:10] <- 0
+    remove <- manage_na(raman_hdpe, ig = c(NA, 0), type = "remove") 
+    expect_equal(length(remove$spectra[[1]]), length(raman_hdpe$spectra[[1]]) - 10)
+})
+
+
 test_that("manage_na works as expected", {
     data(raman_hdpe)
     raman_hdpe$spectra[[1]][3:nrow(raman_hdpe$spectra)] <- NA
@@ -30,3 +38,4 @@ test_that("manage_na works as expected", {
     raman_hdpe$spectra[[1]][1:nrow(raman_hdpe$spectra)] <- NA
     manage_na(raman_hdpe, fun = make_rel) |> expect_error()
 })
+
