@@ -78,8 +78,8 @@ test_that("match_spec() returns correct structure with AI", {
     expect_silent()
   nrow(matches) |> expect_equal(1)
   names(matches) |> expect_contains(c("x", "y", "z", "value", "name"))
-  round(matches$value, 2) |> expect_equal(0.52)
-  grepl("polyamide", matches$name) |> expect_true()
+  round(matches$value, 2) |> expect_equal(0.53)
+  grepl("polyolefin", matches$name) |> expect_true()
 })
 
 test_that("match_spec() handles input errors correctly", {
