@@ -3,9 +3,9 @@ tmp <- file.path(tempdir(), "OpenSpecy-testthat")
 dir.create(tmp, showWarnings = F)
 
 test_that("ENVI files are read", {
-  tiny_map <- read_extdata("CA_tiny_map.zip") |> read_zip() |>
+  tiny_map <- read_extdata("CA_tiny_map.zip") |> read_any() |>
     expect_silent()
-  read_extdata("CA_tiny_map.zip") |> read_zip(share = tmp) |>
+  read_extdata("CA_tiny_map.zip") |> read_any(share = tmp) |>
     expect_message() |> expect_warning()
 
   expect_s3_class(tiny_map, "OpenSpecy")
